@@ -8,8 +8,17 @@ from rich import print
 
 import osxphotos
 from osxphotos._constants import _PHOTOS_4_VERSION, _UNKNOWN_PLACE
+from osxphotos.queryoptions import query_options_from_kwargs
 
-from .common import DB_ARGUMENT, DB_OPTION, JSON_OPTION, OSXPHOTOS_HIDDEN, get_photos_db
+from .cli_params import (
+    DB_ARGUMENT,
+    DB_OPTION,
+    JSON_OPTION,
+    QUERY_OPTIONS,
+    TIMESTAMP_OPTION,
+    VERBOSE_OPTION,
+)
+from .common import OSXPHOTOS_HIDDEN, get_photos_db
 from .list import _list_libraries
 from .verbose import verbose_print
 
@@ -24,30 +33,35 @@ from .verbose import verbose_print
     + "can also use albums, persons, keywords, photos to dump related attributes.",
     multiple=True,
 )
-@click.option(
-    "--uuid",
-    metavar="UUID",
-    help="Use with '--dump photos' to dump only certain UUIDs. "
-    "May be repeated to include multiple UUIDs.",
-    multiple=True,
-)
-@click.option("--verbose", "-V", "verbose", is_flag=True, help="Print verbose output.")
+@VERBOSE_OPTION
+@TIMESTAMP_OPTION
+@QUERY_OPTIONS
 @click.pass_obj
 @click.pass_context
-def debug_dump(ctx, cli_obj, db, photos_library, dump, uuid, verbose):
-    """Print out debug info"""
+def debug_dump(
+    ctx, cli_obj, db, photos_library, dump, verbose_flag, timestamp, **kwargs
+):
+    """Print out debug info.
 
-    verbose_ = verbose_print(verbose, rich=True)
-    db = get_photos_db(*photos_library, db, cli_obj.db)
+    When run with --dump photos, any of the query options can be used to limit the
+    photos printed.  For example, to print info on currently selected photos:
+
+    osxphotos debug-dump --dump photos --selected
+    """
+
+    verbose = verbose_print(verbose_flag, timestamp)
+    db = get_photos_db(*photos_library, db, cli_obj.db if cli_obj else None)
     if db is None:
         click.echo(ctx.obj.group.commands["debug-dump"].get_help(ctx), err=True)
         click.echo("\n\nLocated the following Photos library databases: ", err=True)
         _list_libraries()
         return
 
+    query_options = query_options_from_kwargs(**kwargs)
+
     start_t = time.perf_counter()
     print(f"Opening database: {db}")
-    photosdb = osxphotos.PhotosDB(dbfile=db, verbose=verbose_)
+    photosdb = osxphotos.PhotosDB(dbfile=db, verbose=verbose)
     stop_t = time.perf_counter()
     print(f"Done; took {(stop_t-start_t):.2f} seconds")
 
@@ -78,16 +92,14 @@ def debug_dump(ctx, cli_obj, db, photos_library, dump, uuid, verbose):
             print("_dbpersons_fullname:")
             pprint.pprint(photosdb._dbpersons_fullname)
         elif attr == "photos":
-            if uuid:
-                for uuid_ in uuid:
-                    print(f"_dbphotos['{uuid_}']:")
-                    try:
-                        pprint.pprint(photosdb._dbphotos[uuid_])
-                    except KeyError:
-                        print(f"Did not find uuid {uuid_} in _dbphotos")
-            else:
-                print("_dbphotos:")
-                pprint.pprint(photosdb._dbphotos)
+            photos = photosdb.query(options=query_options)
+            uuid = [photo.uuid for photo in photos]
+            for uuid_ in uuid:
+                print(f"_dbphotos['{uuid_}']:")
+                try:
+                    pprint.pprint(photosdb._dbphotos[uuid_])
+                except KeyError:
+                    print(f"Did not find uuid {uuid_} in _dbphotos")
         else:
             try:
                 val = getattr(photosdb, attr)
