@@ -1,9 +1,6 @@
 """import command for osxphotos CLI to import photos into Photos"""
 
-# Note: the style in this module is a bit different than much of the other osxphotos code
-# As an experiment, I've used mostly functions instead of classes (e.g. the report writer
-# functions vs ReportWriter class used by export) and I've kept everything for import
-# self-contained in this one file
+from __future__ import annotations
 
 import csv
 import datetime
@@ -30,6 +27,7 @@ from strpdatetime import strpdatetime
 
 from osxphotos._constants import _OSXPHOTOS_NONE_SENTINEL
 from osxphotos._version import __version__
+from osxphotos.cli.cli_params import TIMESTAMP_OPTION, VERBOSE_OPTION
 from osxphotos.cli.common import get_data_dir
 from osxphotos.cli.help import HELP_WIDTH
 from osxphotos.cli.param_types import FunctionCall, StrpDateTimePattern, TemplateString
@@ -47,18 +45,17 @@ from osxphotos.phototemplate import PhotoTemplate, RenderOptions
 from osxphotos.sqlitekvstore import SQLiteKVStore
 from osxphotos.utils import pluralize
 
-from .click_rich_echo import (
-    rich_click_echo,
-    rich_echo_error,
-    set_rich_console,
-    set_rich_theme,
-    set_rich_timestamp,
-)
-from .color_themes import get_theme
-from .common import THEME_OPTION
+from .cli_params import THEME_OPTION
+from .click_rich_echo import rich_click_echo, rich_echo_error
 from .rich_progress import rich_progress
 from .verbose import get_verbose_console, verbose_print
 
+# Note: the style in this module is a bit different than much of the other osxphotos code
+# As an experiment, I've used mostly functions instead of classes (e.g. the report writer
+# functions vs ReportWriter class used by export) and I've kept everything for import
+# self-contained in this one file
+
+
 MetaData = namedtuple("MetaData", ["title", "description", "keywords", "location"])
 
 OSXPHOTOS_ABOUT_STRING = f"Created by osxphotos version {__version__} (https://github.com/RhetTbull/osxphotos) on {datetime.datetime.now()}"
@@ -165,7 +162,8 @@ def import_photo(
     Args:
         filepath: path to the file to import
         dup_check: enable or disable Photo's duplicate check on import
-        verbose: Callable"""
+        verbose: Callable
+    """
     if imported := PhotosLibrary().import_photos(
         [filepath], skip_duplicate_check=not dup_check
     ):
@@ -207,7 +205,7 @@ def add_photo_to_albums(
     split_folder: str,
     exiftool_path: Path,
     verbose: Callable[..., None],
-):
+) -> list[str]:
     """Add photo to one or more albums"""
     albums = []
     for a in album:
@@ -225,6 +223,7 @@ def add_photo_to_albums(
             a, verbose=verbose, split_folder=split_folder, rich=True
         )
         photos_album.add(photo)
+    return albums
 
 
 def clear_photo_metadata(photo: Photo, filepath: Path, verbose: Callable[..., None]):
@@ -319,6 +318,8 @@ def location_from_file(
                 latitude = -latitude
             elif latitude_ref != "N":
                 latitude = None
+        if latitude is None:
+            latitude = metadata.get("XMP:GPSLatitude")
         if longitude := metadata.get("EXIF:GPSLongitude"):
             longitude = float(longitude)
             longitude_ref = metadata.get("EXIF:GPSLongitudeRef")
@@ -326,6 +327,8 @@ def location_from_file(
                 longitude = -longitude
             elif longitude_ref != "E":
                 longitude = None
+        if longitude is None:
+            longitude = metadata.get("XMP:GPSLongitude")
         if latitude is None or longitude is None:
             # maybe it's a video
             if lat_lon := metadata.get("QuickTime:GPSCoordinates") or metadata.get(
@@ -344,7 +347,11 @@ def location_from_file(
     return latitude, longitude
 
 
-def set_photo_metadata(photo: Photo, metadata: MetaData, merge_keywords: bool):
+def set_photo_metadata(
+    photo: Photo,
+    metadata: MetaData,
+    merge_keywords: bool,
+) -> MetaData:
     """Set metadata (title, description, keywords) for a Photo object"""
     photo.title = metadata.title
     photo.description = metadata.description
@@ -354,6 +361,7 @@ def set_photo_metadata(photo: Photo, metadata: MetaData, merge_keywords: bool):
             keywords.extend(old_keywords)
             keywords = list(set(keywords))
     photo.keywords = keywords
+    return MetaData(metadata.title, metadata.description, keywords, metadata.location)
 
 
 def set_photo_metadata_from_exiftool(
@@ -362,12 +370,12 @@ def set_photo_metadata_from_exiftool(
     exiftool_path: str,
     merge_keywords: bool,
     verbose: Callable[..., None],
-):
+) -> MetaData:
     """Set photo's metadata by reading metadata form file with exiftool"""
     verbose(f"Setting metadata and location from EXIF for [filename]{filepath.name}[/]")
     metadata = metadata_from_file(filepath, exiftool_path)
     if any([metadata.title, metadata.description, metadata.keywords]):
-        set_photo_metadata(photo, metadata, merge_keywords)
+        metadata = set_photo_metadata(photo, metadata, merge_keywords)
         verbose(f"Set metadata for [filename]{filepath.name}[/]:")
         verbose(
             f"title='{metadata.title}', description='{metadata.description}', keywords={metadata.keywords}"
@@ -383,6 +391,7 @@ def set_photo_metadata_from_exiftool(
         )
     else:
         verbose(f"No location to set for [filename]{filepath.name}[/]")
+    return metadata
 
 
 def set_photo_title(
@@ -392,7 +401,7 @@ def set_photo_title(
     title_template: str,
     exiftool_path: str,
     verbose: Callable[..., None],
-):
+) -> str:
     """Set title of photo"""
     title_text = render_photo_template(
         filepath, relative_filepath, title_template, exiftool_path
@@ -408,6 +417,9 @@ def set_photo_title(
             f"Setting title of photo [filename]{filepath.name}[/] to '{title_text[0]}'"
         )
         photo.title = title_text[0]
+        return title_text[0]
+    else:
+        return ""
 
 
 def set_photo_description(
@@ -417,7 +429,7 @@ def set_photo_description(
     description_template: str,
     exiftool_path: str,
     verbose: Callable[..., None],
-):
+) -> str:
     """Set description of photo"""
     description_text = render_photo_template(
         filepath, relative_filepath, description_template, exiftool_path
@@ -433,6 +445,9 @@ def set_photo_description(
             f"Setting description of photo [filename]{filepath.name}[/] to '{description_text[0]}'"
         )
         photo.description = description_text[0]
+        return description_text[0]
+    else:
+        return ""
 
 
 def set_photo_keywords(
@@ -443,7 +458,7 @@ def set_photo_keywords(
     exiftool_path: str,
     merge: bool,
     verbose: Callable[..., None],
-):
+) -> list[str]:
     """Set keywords of photo"""
     keywords = []
     for keyword in keyword_template:
@@ -456,6 +471,7 @@ def set_photo_keywords(
                 keywords = list(set(keywords))
         verbose(f"Setting keywords of photo [filename]{filepath.name}[/] to {keywords}")
         photo.keywords = keywords
+    return keywords
 
 
 def set_photo_location(
@@ -463,17 +479,18 @@ def set_photo_location(
     filepath: Path,
     location: Tuple[float, float],
     verbose: Callable[..., None],
-):
+) -> tuple[float, float]:
     """Set location of photo"""
     verbose(
         f"Setting location of photo [filename]{filepath.name}[/] to {location[0]}, {location[1]}"
     )
     photo.location = location
+    return location
 
 
 def set_photo_date_from_filename(
     photo: Photo, filepath: Path, parse_date: str, verbose: Callable[..., None]
-):
+) -> datetime.datetime | None:
     """Set date of photo from filename"""
     # TODO: handle timezone (use code from timewarp), for now convert timezone to local timezone
     try:
@@ -491,11 +508,12 @@ def set_photo_date_from_filename(
         verbose(
             f"[warning]Could not parse date from filename [filename]{filepath.name}[/][/]"
         )
-        return
+        return None
     verbose(
         f"Setting date of photo [filename]{filepath.name}[/] to [time]{date.strftime('%Y-%m-%d %H:%M:%S')}[/]"
     )
     photo.date = date
+    return date
 
 
 def get_relative_filepath(filepath: Path, relative_to: Optional[str]) -> Path:
@@ -588,6 +606,8 @@ def check_templates_and_exit(
 
 @dataclass
 class ReportRecord:
+    """Dataclass that records metadata on each file imported for writing to report"""
+
     albums: List[str] = field(default_factory=list)
     description: str = ""
     error: bool = False
@@ -615,6 +635,13 @@ class ReportRecord:
         )
         return cls(**dict_data)
 
+    def update_from_metadata(self, metadata: MetaData):
+        """Update a ReportRecord with data from a MetaData"""
+        self.title = metadata.title
+        self.description = metadata.description
+        self.keywords = metadata.keywords
+        self.location = metadata.location
+
     def asdict(self):
         return asdict(self)
 
@@ -628,15 +655,15 @@ class ReportRecord:
 
 def update_report_record(report_record: ReportRecord, photo: Photo, filepath: Path):
     """Update a ReportRecord with data from a Photo"""
-    report_record.albums = [a.title for a in photo.albums]
-    report_record.description = photo.description
+
+    # do not update albums as they are added to the report record as they are imported (#934)
     report_record.filename = filepath.name
     report_record.filepath = filepath
-    report_record.imported = True
+    report_record.uuid = photo.uuid
+    report_record.title = photo.title
+    report_record.description = photo.description
     report_record.keywords = photo.keywords
     report_record.location = photo.location
-    report_record.title = photo.title
-    report_record.uuid = photo.uuid
 
     return report_record
 
@@ -1329,10 +1356,8 @@ class ImportCommand(click.Command):
     help="If used with --report, add data to existing report file instead of overwriting it. "
     "See also --report.",
 )
-@click.option("--verbose", "-V", "verbose_", is_flag=True, help="Print verbose output.")
-@click.option(
-    "--timestamp", "-T", is_flag=True, help="Add time stamp to verbose output"
-)
+@VERBOSE_OPTION
+@TIMESTAMP_OPTION
 @click.option(
     "--no-progress", is_flag=True, help="Do not display progress bar during import."
 )
@@ -1386,19 +1411,12 @@ def import_cli(
     theme,
     timestamp,
     title,
-    verbose_,
+    verbose_flag,
     walk,
 ):
     """Import photos and videos into Photos."""
 
-    color_theme = get_theme(theme)
-    verbose = verbose_print(
-        verbose_, timestamp, rich=True, theme=color_theme, highlight=False
-    )
-    # set console for rich_echo to be same as for verbose_
-    set_rich_console(get_verbose_console())
-    set_rich_theme(color_theme)
-    set_rich_timestamp(timestamp)
+    verbose = verbose_print(verbose=verbose_flag, timestamp=timestamp, theme=theme)
 
     if not files:
         echo("Nothing to import", err=True)
@@ -1473,11 +1491,13 @@ def import_cli(
             report_data[filepath] = ReportRecord(
                 filepath=filepath, filename=filepath.name
             )
+            report_record = report_data[filepath]
             photo, error = import_photo(filepath, dup_check, verbose)
             if error:
                 error_count += 1
-                report_data[filepath].error = True
+                report_record.error = True
                 continue
+            report_record.imported = True
             imported_count += 1
 
             if clear_metadata:
@@ -1488,12 +1508,21 @@ def import_cli(
 
             if exiftool:
                 set_photo_metadata_from_exiftool(
-                    photo, filepath, exiftool_path, merge_keywords, verbose
+                    photo,
+                    filepath,
+                    exiftool_path,
+                    merge_keywords,
+                    verbose,
                 )
 
             if title:
                 set_photo_title(
-                    photo, filepath, relative_filepath, title, exiftool_path, verbose
+                    photo,
+                    filepath,
+                    relative_filepath,
+                    title,
+                    exiftool_path,
+                    verbose,
                 )
 
             if description:
@@ -1522,9 +1551,10 @@ def import_cli(
 
             if parse_date:
                 set_photo_date_from_filename(photo, filepath, parse_date, verbose)
+                # TODO: ReportRecord doesn't currently record date
 
             if album:
-                add_photo_to_albums(
+                report_record.albums = add_photo_to_albums(
                     photo,
                     filepath,
                     relative_filepath,
@@ -1539,14 +1569,15 @@ def import_cli(
                     # post function is tuple of (function, filename.py::function_name)
                     verbose(f"Calling post-function [bold]{function[1]}")
                     try:
-                        function[0](photo, filepath, verbose)
+                        function[0](photo, filepath, verbose, report_record)
                     except Exception as e:
                         rich_echo_error(
                             f"[error]Error running post-function [italic]{function[1]}[/italic]: {e}"
                         )
 
-            update_report_record(report_data[filepath], photo, filepath)
-            import_db.set(str(filepath), report_data[filepath])
+            # update report data
+            update_report_record(report_record, photo, filepath)
+            import_db.set(str(filepath), report_record)
 
             progress.advance(task)
 
