@@ -1,43 +1,46 @@
 """ Fix time / date / timezone for photos in Apple Photos """
 
-import datetime
-import os
+from __future__ import annotations
+
 import sys
 from functools import partial
 from textwrap import dedent
-from typing import Callable, Optional
 
 import click
-from photoscript import Photo, PhotosLibrary
+from photoscript import PhotosLibrary
 from rich.console import Console
 
 from osxphotos._constants import APP_NAME
+from osxphotos._version import __version__
 from osxphotos.compare_exif import PhotoCompare
+from osxphotos.crash_reporter import crash_reporter, set_crash_data
 from osxphotos.datetime_utils import datetime_naive_to_local, datetime_to_new_tz
 from osxphotos.exif_datetime_updater import ExifDateTimeUpdater
 from osxphotos.exiftool import get_exiftool_path
+from osxphotos.photodates import (
+    get_photo_date_added,
+    set_photo_date_added,
+    set_photo_date_from_filename,
+    update_photo_date_time,
+    update_photo_from_function,
+    update_photo_time_for_new_timezone,
+)
 from osxphotos.photosalbum import PhotosAlbumPhotoScript
 from osxphotos.phototz import PhotoTimeZone, PhotoTimeZoneUpdater
-from osxphotos.timeutils import update_datetime
-from osxphotos.timezones import Timezone
 from osxphotos.utils import noop, pluralize
 
-from .click_rich_echo import (
-    rich_click_echo,
-    rich_echo,
-    rich_echo_error,
-    set_rich_console,
-    set_rich_theme,
-    set_rich_timestamp,
-)
+from .cli_params import THEME_OPTION, TIMESTAMP_OPTION, VERBOSE_OPTION
+from .click_rich_echo import rich_click_echo as echo
+from .click_rich_echo import rich_echo_error as echo_error
 from .color_themes import get_theme
-from .common import THEME_OPTION
+from .common import OSXPHOTOS_CRASH_LOG
 from .darkmode import is_dark_mode
 from .help import HELP_WIDTH, rich_text
 from .param_types import (
     DateOffset,
     DateTimeISO8601,
     FunctionCall,
+    StrpDateTimePattern,
     TimeOffset,
     TimeString,
     UTCOffset,
@@ -49,110 +52,6 @@ from .verbose import get_verbose_console, verbose_print
 DATETIME_FORMAT = "%Y-%m-%d %H:%M:%S%z"
 
 
-def update_photo_date_time(
-    photo: Photo,
-    date,
-    time,
-    date_delta,
-    time_delta,
-    verbose_print: Callable,
-):
-    """Update date, time in photo"""
-    photo_date = photo.date
-    new_photo_date = update_datetime(
-        photo_date, date=date, time=time, date_delta=date_delta, time_delta=time_delta
-    )
-    filename = photo.filename
-    uuid = photo.uuid
-    if new_photo_date != photo_date:
-        photo.date = new_photo_date
-        verbose_print(
-            f"Updated date/time for photo [filename]{filename}[/filename] "
-            f"([uuid]{uuid}[/uuid]) from: [time]{photo_date}[/time] to [time]{new_photo_date}[/time]"
-        )
-    else:
-        verbose_print(
-            f"Skipped date/time update for photo [filename]{filename}[/filename] "
-            f"([uuid]{uuid}[/uuid]): nothing to do"
-        )
-
-
-def update_photo_time_for_new_timezone(
-    library_path: str,
-    photo: Photo,
-    new_timezone: Timezone,
-    verbose_print: Callable,
-):
-    """Update time in photo to keep it the same time but in a new timezone
-
-    For example, photo time is 12:00+0100 and new timezone is +0200,
-    so adjust photo time by 1 hour so it will now be 12:00+0200 instead of
-    13:00+0200 as it would be with no adjustment to the time"""
-    old_timezone = PhotoTimeZone(library_path=library_path).get_timezone(photo)[0]
-    # need to move time in opposite direction of timezone offset so that
-    # photo time is the same time but in the new timezone
-    delta = old_timezone - new_timezone.offset
-    photo_date = photo.date
-    new_photo_date = update_datetime(
-        dt=photo_date, time_delta=datetime.timedelta(seconds=delta)
-    )
-    filename = photo.filename
-    uuid = photo.uuid
-    if photo_date != new_photo_date:
-        photo.date = new_photo_date
-        verbose_print(
-            f"Adjusted date/time for photo [filename]{filename}[/filename] ([uuid]{uuid}[/uuid]) to match "
-            f"previous time [time]{photo_date}[time] but in new timezone [tz]{new_timezone}[/tz]."
-        )
-    else:
-        verbose_print(
-            f"Skipping date/time update for photo [filename]{filename}[/filename] ([uuid]{photo.uuid}[/uuid]), "
-            f"already matches new timezone [tz]{new_timezone}[/tz]"
-        )
-
-
-def update_photo_from_function(
-    library_path: str,
-    function: Callable,
-    verbose_print: Callable,
-    photo: Photo,
-    path: Optional[str],
-):
-    """Update photo from function call"""
-    photo_tz_sec, _, photo_tz_name = PhotoTimeZone(
-        library_path=library_path
-    ).get_timezone(photo)
-    dt_new, tz_new = function(
-        photo=photo,
-        path=path,
-        tz_sec=photo_tz_sec,
-        tz_name=photo_tz_name,
-        verbose=verbose_print,
-    )
-    if dt_new != photo.date:
-        old_date = photo.date
-        photo.date = dt_new
-        verbose_print(
-            f"Updated date/time for photo [filename]{photo.filename}[/filename] "
-            f"([uuid]{photo.uuid}[/uuid]) from: [time]{old_date}[/time] to [time]{dt_new}[/time]"
-        )
-    else:
-        verbose_print(
-            f"Skipped date/time update for photo [filename]{photo.filename}[/filename] "
-            f"([uuid]{photo.uuid}[/uuid]): nothing to do"
-        )
-    if tz_new != photo_tz_sec:
-        tz_updater = PhotoTimeZoneUpdater(
-            timezone=Timezone(tz_new), verbose=verbose_print, library_path=library_path
-        )
-        tz_updater.update_photo(photo)
-    else:
-        verbose_print(
-            f"Skipped timezone update for photo [filename]{photo.filename}[/filename] "
-            f"([uuid]{photo.uuid}[/uuid]): nothing to do"
-        )
-
-
 class TimeWarpCommand(click.Command):
     """Custom click.Command that overrides get_help() to show additional help info for export"""
 
@@ -214,6 +113,14 @@ For this to work, you'll need to install the third-party exiftool (https://exift
 
 *Note on timezones and times*: In Photos, when you change the timezone, Photos assumes the time itself was correct for the previous timezone and adjusts the time accordingly to the new timezone.  E.g. if the photo's time is `13:00` and the timezone is `GMT -07:00` and you adjust the timezone one hour east to `GMT -06:00`, Photos will change the time of the photo to `14:00`.  osxphotos timewarp follows this behavior.  Using `--match-time` allows you to adjust the timezone but keep the same time without adjustment. For example, if your camera clock was correct but lacked timezone information and you took photos in one timezone but imported them to photos in another, Photos will add the timezone of the computer at time of import.  You can use osxphotos timewarp to adjust the timezone but keep the time using `--match-time`.
 
+**Update the date the photos were added to Photos**
+
+`osxphotos timewarp --date-added 2021-09-10`
+
+**Update the date the photos were added to Photos to match the date of the photo**
+
+`osxphotos timewarp --date-added-from-photo`
+
 **Compare the date/time/timezone of selected photos with the date/time/timezone in the photos' original EXIF metadata**
 
 `osxphotos timewarp --compare-exif`
@@ -223,6 +130,40 @@ if the EXIF data is missing, use the file modification date/time; show verbose o
 
 `osxphotos timewarp --pull-exif --use-file-time --verbose`
 
+## Parsing Dates/Times from Filenames
+
+The --parse-date option allows you to parse dates/times from the original filename of the photo.
+This is useful if you files with dates/times embedded in the filename but not in the metadata.
+
+
+The argument to `--parse-date` is a pattern string that is used to parse the date/time
+from the filename. The pattern string is a superset of the python `strftime/strptime`
+format with the following additions:
+
+- *: Match any number of characters
+- ^: Match the beginning of the string
+- $: Match the end of the string
+- {n}: Match exactly n characters
+- {n,}: Match at least n characters
+- {n,m}: Match at least n characters and at most m characters
+- In addition to `%%` for a literal `%`, the following format codes are supported: 
+    `%^`, `%$`, `%*`, `%|`, `%{`, `%}` for `^`, `$`, `*`, `|`, `{`, `}` respectively
+- |: join multiple format codes; each code is tried in order until one matches
+- Unlike the standard library, the leading zero is not optional for 
+    %d, %m, %H, %I, %M, %S, %j, %U, %W, and %V
+- For optional leading zero, use %-d, %-m, %-H, %-I, %-M, %-S, %-j, %-U, %-W, and %-V
+
+For more information on strptime format codes, see: 
+https://docs.python.org/3/library/datetime.html?highlight=strptime#strftime-and-strptime-format-codes
+
+**Note**: The time zone of the parsed date/time is assumed to be the local time zone.
+If the parse pattern includes a time zone, the photo's time will be converted from
+the specified time zone to the local time zone. osxphotos import does not
+currently support setting the time zone of imported photos.
+See also `osxphotos help timewarp` for more information on the timewarp
+command which can be used to change the time zone of photos after import.
+
+
 """
                 ),
                 width=formatter.width,
@@ -279,6 +220,25 @@ if the EXIF data is missing, use the file modification date/time; show verbose o
     "This is the same behavior exhibited by Photos when manually adjusting timezone in the Get Info window. "
     "See also --match-time. ",
 )
+@click.option(
+    "--date-added",
+    metavar="DATE",
+    type=DateTimeISO8601(),
+    help="Set date/time added for selected photos. "
+    "This changes the date added or imported date in Photos but "
+    "does not change the date/time/timezone of the photo itself. "
+    "This is useful for removing photos from the Recents album, "
+    "for example if you have imported old scanned photos. "
+    "Format is 'YYYY-MM-DD' or 'YYYY-MM-DD HH:MM:SS'. "
+    "If time is not included, midnight is assumed.",
+)
+@click.option(
+    "--date-added-from-photo",
+    is_flag=True,
+    help="Set date/time added for selected photos to the date/time the photo was taken. "
+    "This changes the date added or imported date in Photos but "
+    "does not change the date/time/timezone of the photo itself. ",
+)
 @click.option(
     "--inspect",
     "-i",
@@ -322,6 +282,19 @@ if the EXIF data is missing, use the file modification date/time; show verbose o
     "Requires the third-party exiftool utility be installed (see https://exiftool.org/). "
     "See also --push-exif.",
 )
+@click.option(
+    "--parse-date",
+    "-M",
+    metavar="DATE_PATTERN",
+    type=StrpDateTimePattern(),
+    help="Parse date from filename using DATE_PATTERN and set photo's date to match. "
+    "If file does not match DATE_PATTERN, the date will not be changed. "
+    "DATE_PATTERN is a strptime-compatible pattern with extensions as pattern described below. "
+    "If DATE_PATTERN matches time zone information, the photo's timezone will be set to match. "
+    "For example, if your photos are named 'IMG_1234_2022_11_23_12_34_56.jpg' where the date/time is "
+    "'2022-11-23 12:34:56', you could use the pattern '%Y_%m_%d_%H_%M_%S' or "
+    "'IMG_*_%Y_%m_%d_%H_%M_%S' to further narrow the pattern to only match files with 'IMG_xxxx_' in the name.",
+)
 @click.option(
     "--function",
     "-F",
@@ -363,7 +336,8 @@ if the EXIF data is missing, use the file modification date/time; show verbose o
     help="When used with --compare-exif, adds any photos with date/time/timezone differences "
     "between Photos/EXIF to album ALBUM.  If ALBUM does not exist, it will be created.",
 )
-@click.option("--verbose", "-V", "verbose", is_flag=True, help="Show verbose output.")
+@VERBOSE_OPTION
+@TIMESTAMP_OPTION
 @click.option(
     "--library",
     "-L",
@@ -379,19 +353,6 @@ if the EXIF data is missing, use the file modification date/time; show verbose o
     type=click.Path(exists=True),
     help="Optional path to exiftool executable (will look in $PATH if not specified) for those options which require exiftool.",
 )
-@click.option(
-    "--output-file",
-    "-o",
-    type=click.File(mode="w", lazy=False),
-    help="Output file. If not specified, output is written to stdout.",
-)
-@click.option(
-    "--terminal-width",
-    "-w",
-    type=int,
-    help="Terminal width in characters.",
-    hidden=True,
-)
 @click.option("--timestamp", is_flag=True, help="Add time stamp to verbose output")
 @THEME_OPTION
 @click.option(
@@ -404,12 +365,21 @@ if the EXIF data is missing, use the file modification date/time; show verbose o
     is_flag=True,
     help="Bypass confirmation prompt.  Use with caution.",
 )
+@crash_reporter(
+    OSXPHOTOS_CRASH_LOG,
+    "[red]Something went wrong and osxphotos encountered an error:[/red]",
+    "osxphotos crash log",
+    "Please file a bug report at https://github.com/RhetTbull/osxphotos/issues with the crash log attached.",
+    f"osxphotos version: {__version__}",
+)
 def timewarp(
     date,
     date_delta,
     time,
     time_delta,
     timezone,
+    date_added,
+    date_added_from_photo,
     inspect,
     compare_exif,
     push_exif,
@@ -419,12 +389,11 @@ def timewarp(
     use_file_time,
     add_to_album,
     exiftool_path,
-    verbose,
+    verbose_flag,
     library,
     theme,
+    parse_date,
     plain,
-    output_file,
-    terminal_width,
     timestamp,
     force,
 ):
@@ -436,24 +405,30 @@ def timewarp(
     See Timewarp Overview below for additional information.
     """
 
+    set_crash_data("locals", locals())
+
     # check constraints
     if not any(
         [
-            date,
-            date_delta,
-            time,
-            time_delta,
-            timezone,
-            inspect,
             compare_exif,
-            push_exif,
-            pull_exif,
+            date_added_from_photo,
+            date_added,
+            date_delta,
+            date,
             function,
+            inspect,
+            parse_date,
+            pull_exif,
+            push_exif,
+            time_delta,
+            time,
+            timezone,
         ]
     ):
         raise click.UsageError(
             "At least one of --date, --date-delta, --time, --time-delta, "
-            "--timezone, --inspect, --compare-exif, --push-exif, --pull-exif, --function "
+            "--timezone, --inspect, --compare-exif, --push-exif, --pull-exif, "
+            "--parse-date, --function, --date-added, or --date-added-from-photo "
             "must be specified."
         )
 
@@ -469,54 +444,28 @@ def timewarp(
     if add_to_album and not compare_exif:
         raise click.UsageError("--add-to-album must be used with --compare-exif.")
 
-    # configure colored rich output
-    # TODO: this is all a little hacky, find a better way to do this
-    color_theme = get_theme(theme)
-    verbose_ = verbose_print(
-        verbose,
-        timestamp,
-        rich=True,
-        theme=color_theme,
-        highlight=False,
-        file=output_file,
-    )
-    # set console for rich_echo to be same as for verbose_
-    terminal_width = terminal_width or (1000 if output_file else None)
-    if output_file:
-        set_rich_console(Console(file=output_file, width=terminal_width))
-    elif terminal_width:
-        set_rich_console(
-            Console(
-                file=sys.stdout,
-                theme=color_theme,
-                force_terminal=True,
-                width=terminal_width,
-            )
-        )
-    else:
-        set_rich_console(get_verbose_console(theme=color_theme))
-    set_rich_theme(color_theme)
+    verbose = verbose_print(verbose=verbose_flag, timestamp=timestamp, theme=theme)
 
     if any([compare_exif, push_exif, pull_exif]):
         exiftool_path = exiftool_path or get_exiftool_path()
-        verbose_(f"exiftool path: [filename]{exiftool_path}[/filename]")
+        verbose(f"exiftool path: [filename]{exiftool_path}[/filename]")
 
     try:
         photos = PhotosLibrary().selection
         if not photos:
-            rich_echo_error("[warning]No photos selected[/]")
+            echo_error("[warning]No photos selected[/]")
             sys.exit(0)
     except Exception as e:
         # AppleScript error -1728 occurs if user attempts to get selected photos in a Smart Album
         if "(-1728)" in str(e):
-            rich_echo_error(
+            echo_error(
                 "[error]Could not get selected photos. Ensure photos is open and photos are selected. "
                 "If you have selected photos and you see this message, it may be because the selected photos are in a Photos Smart Album. "
                 f"{APP_NAME} cannot access photos in a Smart Album.  Select the photos in a regular album or in 'All Photos' view. "
                 "Another option is to create a new album using 'File | New Album With Selection' then select the photos in the new album.[/]",
             )
         else:
-            rich_echo_error(
+            echo_error(
                 f"[error]Could not get selected photos. Ensure Photos is open and photos to process are selected. {e}[/]",
             )
         sys.exit(1)
@@ -525,14 +474,17 @@ def timewarp(
     if (
         any(
             [
-                date,
+                date_added_from_photo,
+                date_added,
                 date_delta,
-                time,
-                time_delta,
-                timezone,
-                push_exif,
-                pull_exif,
+                date,
                 function,
+                parse_date,
+                pull_exif,
+                push_exif,
+                time_delta,
+                time,
+                timezone,
             ]
         )
         and not force
@@ -556,13 +508,37 @@ def timewarp(
         time=time,
         date_delta=date_delta,
         time_delta=time_delta,
-        verbose_print=verbose_,
+        verbose=verbose,
     )
 
     update_photo_time_for_new_timezone_ = partial(
         update_photo_time_for_new_timezone,
         library_path=library,
-        verbose_print=verbose_,
+        verbose=verbose,
+    )
+
+    set_photo_date_from_filename_ = partial(
+        set_photo_date_from_filename,
+        library_path=library,
+        verbose=verbose,
+    )
+
+    set_photo_date_added_ = partial(
+        set_photo_date_added,
+        library_path=library,
+        verbose=verbose,
+        date_added=date_added,
+    )
+
+    set_photo_date_added_from_photo_ = partial(
+        set_photo_date_added,
+        library_path=library,
+        verbose=verbose,
+    )
+
+    get_photo_date_added_ = partial(
+        get_photo_date_added,
+        library_path=library,
     )
 
     if function:
@@ -570,7 +546,7 @@ def timewarp(
             update_photo_from_function,
             library_path=library,
             function=function[0],
-            verbose_print=verbose_,
+            verbose=verbose,
         )
     else:
         update_photo_from_function_ = noop
@@ -578,15 +554,25 @@ def timewarp(
     if inspect:
         tzinfo = PhotoTimeZone(library_path=library)
         if photos:
-            rich_echo(
-                "[filename]filename[/filename], [uuid]uuid[/uuid], [time]photo time (local)[/time], [time]photo time[/time], [tz]timezone offset[/tz], [tz]timezone name[/tz]"
+            echo(
+                "[filename]filename[/filename], [uuid]uuid[/uuid], "
+                "[time]photo time (local)[/time], "
+                "[time]photo time[/time], "
+                "[tz]timezone offset[/tz], [tz]timezone name[/tz], "
+                "[time]date added (local)[/time]"
             )
         for photo in photos:
+            set_crash_data("photo", f"{photo.uuid} {photo.filename}")
             tz_seconds, tz_str, tz_name = tzinfo.get_timezone(photo)
             photo_date_local = datetime_naive_to_local(photo.date)
             photo_date_tz = datetime_to_new_tz(photo_date_local, tz_seconds)
-            rich_echo(
-                f"[filename]{photo.filename}[/filename], [uuid]{photo.uuid}[/uuid], [time]{photo_date_local.strftime(DATETIME_FORMAT)}[/time], [time]{photo_date_tz.strftime(DATETIME_FORMAT)}[/time], [tz]{tz_str}[/tz], [tz]{tz_name}[/tz]"
+            date_added = datetime_naive_to_local(get_photo_date_added_(photo))
+            echo(
+                f"[filename]{photo.filename}[/filename], [uuid]{photo.uuid}[/uuid], "
+                f"[time]{photo_date_local.strftime(DATETIME_FORMAT)}[/time], "
+                f"[time]{photo_date_tz.strftime(DATETIME_FORMAT)}[/time], "
+                f"[tz]{tz_str}[/tz], [tz]{tz_name}[/tz], "
+                f"[time]{date_added.strftime(DATETIME_FORMAT)}[/time]"
             )
         sys.exit(0)
 
@@ -596,14 +582,15 @@ def timewarp(
         if photos:
             photocomp = PhotoCompare(
                 library_path=library,
-                verbose=verbose_,
+                verbose=verbose,
                 exiftool_path=exiftool_path,
             )
             if not album:
-                rich_echo(
+                echo(
                     "filename, uuid, photo time (Photos), photo time (EXIF), timezone offset (Photos), timezone offset (EXIF)"
                 )
         for photo in photos:
+            set_crash_data("photo", f"{photo.uuid} {photo.filename}")
             diff_results = (
                 photocomp.compare_exif_no_markup(photo)
                 if plain
@@ -622,20 +609,20 @@ def timewarp(
             if album:
                 if diff_results.diff:
                     different_photos += 1
-                    verbose_(
+                    verbose(
                         f"Photo {filename} ({uuid}) has different date/time/timezone, adding to album '{album.name}'"
                     )
                     album.add(photo)
                 else:
-                    verbose_(f"Photo {filename} ({uuid}) has same date/time/timezone")
+                    verbose(f"Photo {filename} ({uuid}) has same date/time/timezone")
             else:
-                rich_echo(
+                echo(
                     f"{filename}, {uuid}, "
                     f"{diff_results.photos_date} {diff_results.photos_time}, {diff_results.exif_date} {diff_results.exif_time}, "
                     f"{diff_results.photos_tz}, {diff_results.exif_tz}"
                 )
         if album:
-            rich_echo(
+            echo(
                 f"Compared {len(photos)} photos, found {different_photos} "
                 f"that {pluralize(different_photos, 'is', 'are')} different and "
                 f"added {pluralize(different_photos, 'it', 'them')} to album '{album.name}'."
@@ -644,14 +631,14 @@ def timewarp(
 
     if timezone:
         tz_updater = PhotoTimeZoneUpdater(
-            timezone, verbose=verbose_, library_path=library
+            timezone, verbose=verbose, library_path=library
         )
 
     if any([push_exif, pull_exif, function]):
         # ExifDateTimeUpdater used to get photo path for --function
         exif_updater = ExifDateTimeUpdater(
             library_path=library,
-            verbose=verbose_,
+            verbose=verbose,
             exiftool_path=exiftool_path,
             plain=plain,
         )
@@ -662,34 +649,39 @@ def timewarp(
             f"Processing [num]{num_photos}[/] {pluralize(len(photos), 'photo', 'photos')}",
             total=num_photos,
         )
-        for p in photos:
+        for photo in photos:
+            set_crash_data("photo", f"{photo.uuid} {photo.filename}")
+            if parse_date:
+                set_photo_date_from_filename_(photo, photo.filename, parse_date)
             if pull_exif:
                 exif_updater.update_photos_from_exif(
-                    p, use_file_modify_date=use_file_time
+                    photo, use_file_modify_date=use_file_time
                 )
             if any([date, time, date_delta, time_delta]):
-                update_photo_date_time_(p)
+                update_photo_date_time_(photo)
             if match_time:
                 # need to adjust time before the timezone is updated
                 # or the old timezone will be overwritten in the database
-                update_photo_time_for_new_timezone_(photo=p, new_timezone=timezone)
+                update_photo_time_for_new_timezone_(photo=photo, new_timezone=timezone)
             if timezone:
-                tz_updater.update_photo(p)
+                tz_updater.update_photo(photo)
+            if date_added:
+                set_photo_date_added_(photo)
+            if date_added_from_photo:
+                set_photo_date_added_from_photo_(photo, date_added=photo.date)
             if function:
-                verbose_(f"Calling function [bold]{function[1]}")
-                photo_path = exif_updater.get_photo_path(p)
-                update_photo_from_function_(photo=p, path=photo_path)
+                verbose(f"Calling function [bold]{function[1]}")
+                photo_path = exif_updater.get_photo_path(photo)
+                update_photo_from_function_(photo=photo, path=photo_path)
             if push_exif:
                 # this should be the last step in the if chain to ensure all Photos data is updated
                 # before exiftool is run
-                exif_warn, exif_error = exif_updater.update_exif_from_photos(p)
+                exif_warn, exif_error = exif_updater.update_exif_from_photos(photo)
                 if exif_warn:
-                    rich_echo_error(
-                        f"[warning]Warning running exiftool: {exif_warn}[/]"
-                    )
+                    echo_error(f"[warning]Warning running exiftool: {exif_warn}[/]")
                 if exif_error:
-                    rich_echo_error(f"[error]Error running exiftool: {exif_error}[/]")
+                    echo_error(f"[error]Error running exiftool: {exif_error}[/]")
 
             progress.advance(task)
 
-    rich_echo("Done.")
+    echo("Done.")
