@@ -25,10 +25,13 @@ import shortuuid
 
 from ._constants import UNICODE_FORMAT
 
+logger = logging.getLogger("osxphotos")
+
 __all__ = [
     "dd_to_dms_str",
     "expand_and_validate_filepath",
     "get_last_library_path",
+    "get_macos_version",
     "get_system_library_path",
     "hexdigest",
     "increment_filename_with_count",
@@ -37,6 +40,7 @@ __all__ = [
     "list_directory",
     "list_photo_libraries",
     "load_function",
+    "lock_filename",
     "noop",
     "normalize_fs_path",
     "normalize_unicode",
@@ -46,23 +50,9 @@ __all__ = [
 ]
 
 
-logging.basicConfig(
-    level=logging.DEBUG,
-    format="%(asctime)s - %(levelname)s - %(filename)s - %(lineno)d - %(message)s",
-)
-
 VERSION_INFO_URL = "https://pypi.org/pypi/osxphotos/json"
 
 
-def _get_logger():
-    """Used only for testing
-
-    Returns:
-        logging.Logger object -- logging.Logger object for osxphotos
-    """
-    return logging.Logger(__name__)
-
-
 def noop(*args, **kwargs):
     """do nothing (no operation)"""
     pass
@@ -76,7 +66,7 @@ def lineno(filename):
     return f"{filename}: {line}"
 
 
-def _get_os_version():
+def get_macos_version():
     # returns tuple of str containing OS version
     # e.g. 10.13.6 = ("10", "13", "6")
     version = platform.mac_ver()[0].split(".")
@@ -176,9 +166,9 @@ def get_system_library_path():
     """return the path to the system Photos library as string"""
     """ only works on MacOS 10.15 """
     """ on earlier versions, returns None """
-    _, major, _ = _get_os_version()
+    _, major, _ = get_macos_version()
     if int(major) < 15:
-        logging.debug(
+        logger.debug(
             f"get_system_library_path not implemented for MacOS < 10.15: you have {major}"
         )
         return None
@@ -191,7 +181,7 @@ def get_system_library_path():
         with open(plist_file, "rb") as fp:
             pl = plistload(fp)
     else:
-        logging.debug(f"could not find plist file: {str(plist_file)}")
+        logger.debug(f"could not find plist file: {str(plist_file)}")
         return None
 
     return pl.get("SystemLibraryPath")
@@ -208,7 +198,7 @@ def get_last_library_path():
         with open(plist_file, "rb") as fp:
             pl = plistload(fp)
     else:
-        logging.debug(f"could not find plist file: {str(plist_file)}")
+        logger.debug(f"could not find plist file: {str(plist_file)}")
         return None
 
     # get the IPXDefaultLibraryURLBookmark from com.apple.Photos.plist
@@ -244,7 +234,7 @@ def get_last_library_path():
 
         return photospath
     else:
-        logging.debug("Could not get path to Photos database")
+        logger.debug("Could not get path to Photos database")
         return None
 
 
@@ -379,7 +369,7 @@ def normalize_unicode(value):
 
 
 def increment_filename_with_count(
-    filepath: Union[str, pathlib.Path], count: int = 0
+    filepath: Union[str, pathlib.Path], count: int = 0, lock: bool = False
 ) -> Tuple[str, int]:
     """Return filename (1).ext, etc if filename.ext exists
 
@@ -389,6 +379,7 @@ def increment_filename_with_count(
     Args:
         filepath: str or pathlib.Path; full path, including file name
         count: int; starting increment value
+        lock: bool, if True, creates lock file to reserve filename
 
     Returns:
         tuple of new filepath (or same if not incremented), count
@@ -405,10 +396,13 @@ def increment_filename_with_count(
         count += 1
         dest_new = normalize_fs_path(f"{dest.stem} ({count})")
     dest = dest.parent / f"{dest_new}{dest.suffix}"
+    if lock and not lock_filename(dest):
+        # if lock fails, increment count and try again
+        return increment_filename_with_count(filepath, count + 1, lock=lock)
     return normalize_fs_path(str(dest)), count
 
 
-def increment_filename(filepath: Union[str, pathlib.Path]) -> str:
+def increment_filename(filepath: Union[str, pathlib.Path], lock: bool = False) -> str:
     """Return filename (1).ext, etc if filename.ext exists
 
         If file exists in filename's parent folder with same stem as filename,
@@ -417,16 +411,47 @@ def increment_filename(filepath: Union[str, pathlib.Path]) -> str:
     Args:
         filepath: str or pathlib.Path; full path, including file name
         force: force the file count to increment by at least 1 even if filepath doesn't exist
+        lock: bool, if True, creates lock file to reserve filename
 
     Returns:
         new filepath (or same if not incremented)
 
     Note: This obviously is subject to race condition so using with caution.
     """
-    new_filepath, _ = increment_filename_with_count(filepath)
+    new_filepath, _ = increment_filename_with_count(filepath, lock=lock)
     return new_filepath
 
 
+def lock_filename(filepath: Union[str, pathlib.Path]) -> bool:
+    """Create empty lock file to reserve file.
+        Lock file will have name of filepath with .osxphotos.lock extension.
+
+    Args:
+        filepath: str or pathlib.Path; full path, including file name
+
+    Returns:
+        filepath if lock file created, False if lock file already exists
+    """
+
+    lockfile = pathlib.Path(f"{filepath}.osxphotos.lock")
+    if lockfile.exists():
+        return False
+    lockfile.touch()
+    return filepath
+
+
+def unlock_filename(filepath: Union[str, pathlib.Path]):
+    """Remove lock file created by lock_filename()
+
+    Args:
+        filepath: str or pathlib.Path; full path, including file name
+    """
+
+    lockfile = pathlib.Path(f"{filepath}.osxphotos.lock")
+    if lockfile.exists():
+        lockfile.unlink()
+
+
 def extract_increment_count_from_filename(filepath: Union[str, pathlib.Path]) -> int:
     """Extract a count from end of file name if it exists or 0 if not; count takes forms file (1).ext, file (2).ext, etc."""
     filepath = str(filepath)
@@ -513,3 +538,7 @@ def uuid_to_shortuuid(uuid: str) -> str:
 def shortuuid_to_uuid(short_uuid: str) -> str:
     """Convert shortuuid to uuid"""
     return str(shortuuid.decode(short_uuid)).upper()
+
+def under_test() -> bool:
+    """Return True if running under pytest"""
+    return "pytest" in sys.modules
\ No newline at end of file
